300W-LP Dataset is expanded from 300W, which standardises multiple alignment
databases with 68 landmarks, including AFW, LFPW, HELEN, IBUG and XM2VTS. With
300W, 300W-LP adopt the proposed face profiling to generate 61,225 samples
across large poses (1,786 from IBUG, 5,207 from AFW, 16,556 from LFPW and 37,676
from HELEN, XM2VTS is not used).

The dataset can be employed as the training set for the following computer
vision tasks: face attribute recognition and landmark (or facial part)
localization.
